
#ifndef _C1_op45_
#define _C1_op45_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F68_951(EIF_REFERENCE);
extern void EIF_Minit45(void);

#ifdef __cplusplus
}
#endif

#endif
